/*
******************************************************************************
*
*      File             : oacs.h
*      Version          : 2.0.0
*      Date             : 27 February 2001
*      Author           : Jochen Junkawitsch
*      Description      : header file for OACS selection rules
*
*
******************************************************************************
*/

#ifndef OACS_H_INCLUDED
#define OACS_H_INCLUDED



typedef unsigned char CodecSet;

typedef enum
{
  HR_AMR,
  FR_AMR,
  UMTS_AMR,
  UMTS_AMR_2,
  GSM_EFR,
  GSM_FR,
  GSM_HR
} CodecType;


typedef enum
{
  mode_475 = 1,
  mode_515 = 2,
  mode_590 = 4,
  mode_670 = 8,
  mode_740 = 16,
  mode_795 = 32,
  mode_102 = 64,
  mode_122 = 128
} CodecMode;


  
/* ----------------------------------------------------------------------------------
                                     functions
   ---------------------------------------------------------------------------------- */


CodecSet calc_OACS(CodecSet aCscs, int cmacs, CodecType codecType);
/*
   Calculate the OACS.
   Input parameters:
     - CodecSet aCscs     : common supported codec set (CSCS)
     - int cmacs          : CMACS
     - CodecType codecType: HR_AMR if HR_AMR is involved, else FR_AMR
   Return value: OACS (type CodecSet)
*/



int nModes(CodecSet codecSet);
/*
   Return the number of modes in the codecSet.
*/

int highModeRule(CodecSet lacs, CodecSet dacs, CodecSet oacs);
int lowModeRule (CodecSet lacs, CodecSet dacs, CodecSet oacs, CodecType codecType);


#endif

